#!/usr/bin/bash

# $Author: jeffr $
# $Date: 2023-09-03 08:46:49 -0400 (Sun, 03 Sep 2023) $
# $Revision: 60 $

# Input file
if [ ! $1 ] ; then
	echo 'Input file required.'
	exit 1
else
	if [ ! -f $1 ] ; then
		echo 'Input file does not exist.'
		exit 1
	else
		input_file=$1
	fi
fi

# Output format (default to raw)
if [ ! $2 ] ; then
	out_fmt='raw'
else
	out_fmt=$2
fi

# Hour adjustment (0)
if [ ! $3 ] ; then
	hr_adj=0
else
	hr_adj=$3
fi

# Time zone label (UT)
if [ ! $4 ] ; then
	tz_label='UT'
else
	tz_label=$4
fi

# Ensure a valid format is specified
if  [ $out_fmt != 'raw' ] && [ $out_fmt != 'csv' ] && \
	[ $out_fmt != 'html' ] && [ $out_fmt != 'ps' ] && \
	[ $out_fmt != 'table' ] ; then

	echo 'Unknown output format specified. Output formats include: csv, html, ps, raw, and table.'
	exit 1
fi
	
# Temp files and processing required for all output formats
temp=$(mktemp /tmp/planet-rs.XXXXXXXXX)
temp2=$(mktemp /tmp/planet-rs.XXXXXXXXX)

aa < $input_file | grep -E "rises|sets" > $temp
cat $temp | gawk -v hr_adj="$hr_adj" -v tz_label="$tz_label" -f fmt-raw.awk $temp > $temp2

# Raw output
if [ $out_fmt = 'raw' ] ; then
	echo "Input file: $1"
	cat $temp2
	rm /tmp/planet-rs*
	exit 0
fi

# CSV, HTML, PS, or tabular output
temp3=$(mktemp /tmp/planet-rs.XXXXXXXXX)
temp4=$(mktemp /tmp/planet-rs.XXXXXXXXX)
temp5=$(mktemp /tmp/planet-rs.XXXXXXXXX)

gawk -v rs="rises" -f fmt-csv.awk $temp2 > $temp3
gawk -v rs="sets" -f fmt-csv.awk $temp2 > $temp4
paste -d ',' $temp3 $temp4 > $temp5

# CSV output
if [ $out_fmt = 'csv' ] ; then
	echo "Input file: $1"
	cat $temp5
fi

# HTML output
if [ $out_fmt = 'html' ] ; then
	cat inc/header.html
	gawk -v input_file="$input_file" -f fmt-html.awk $temp5
	cat inc/footer.html
fi

# Tabular or ps
if [ $out_fmt = 'table' ] || [ $out_fmt = 'ps' ]; then
	groff_opt='-T ascii'
	if [ $out_fmt = 'ps' ] ; then 
		groff_opt='-T ps -dpaper=a4 -P -pa4 -ms'
	fi

	temp6=$(mktemp /tmp/planet-rs.XXXXXXXXX)
	sed "s/input_file/$input_file/" inc/header.roff > $temp6
	cat $temp5 >> $temp6
	cat inc/footer.roff >> $temp6

	# Added to address issue with output of extraneous blank lines
	temp7=$(mktemp /tmp/planet-rs.XXXXXXXXX)
	cat $temp6 | groff -t $groff_opt > $temp7
	cat $temp7 | sed -E '/^\s*$/d'
fi

# Clean up
rm /tmp/planet-rs*
exit 0
